@@ -21,7 +21,7 @@ import dbus
 import glib
 
 # keep sync with src/capabilities.c:self_advertised_features
-fixed_features = [ns.SI, ns.IBB, ns.TUBES, ns.IQ_OOB, ns.X_OOB]
+fixed_features = [ns.SI, ns.TUBES, ns.IQ_OOB, ns.X_OOB]
 
 def make_result_iq(iq):
     result = IQ(None, "result")
@@ -220,8 +220,15 @@ def wait_for_contact_in_publish(q, bus, conn, contact_name):
     while handle == 0:
         e = q.expect('dbus-signal', signal='MembersChangedDetailed',
                 path=publish)
+        # Versions of telepathy-glib prior to 0.14.6 incorrectly used the name
+        # 'member-ids'.
+        try:
+            ids = e.args[4]['contact-ids']
+        except KeyError:
+            ids = e.args[4]['member-ids']
+
         for h in e.args[0]:
-            name = e.args[4]['member-ids'][h]
+            name = ids[h]
             if name == contact_name:
                 handle = h
 
